#!/usr/bin/wishx -f

#
# pop.tcl
# by Ashvin Goel <ashvin@ficus.cs.ucla.edu>
#
# Fetches mail via POP.
#


proc pop_init {} {
    global rdb server passwd passwd_list tpasswd_list
    if {[info exists rdb(pop.server)] && [info exists rdb(pop.passwd)]} {
	return
    }
    # set the values of the popserver and the poppasswd
    if {[info exists rdb(pop.server)]} {
	set server $rdb(pop.server)
    }
    frame .f1 -bg $rdb(bg)
    frame .f2 -bg $rdb(bg)
    pack .f1 .f2 -side top
    label .label1 -text "Pop server" -fg $rdb(fg) -bg $rdb(bg)
    entry .server -width 20 -relief sunken -textvariable server
    label .label2 -text "Pop password" -fg $rdb(fg) -bg $rdb(bg)
    entry .passwd -width 14 -relief sunken -textvariable passwd
    button .ok -text OK -command {
	set passwd [join $passwd_list ""]
	unset passwd_list
	unset tpasswd_list
	set_rdb_default pop.server $server
	set_rdb_default pop.passwd $passwd
	destroy .f1
	destroy .f2
    }
    pack .label1 .server -side left -padx 1m -pady 2m -in ".f1"
    pack .label2 .passwd .ok -side left -padx 1m -pady 2m -fill x -in ".f2"
    # This is buggy.
    # The last letter of the password is visible for sometime.
    # TODO: handle delete, erase, kill etc.
    bind .passwd <KeyPress> {
	if {[llength %A]} {
	    lappend passwd_list %A
	    lappend tpasswd_list "*"
	}
    }
    bind .passwd <KeyRelease> {
	set passwd [join $tpasswd_list ""]
    }
}

proc pop_client {} {
    global rdb err1 err2 errorCode

    if {![info exists rdb(pop.server)]} {
	return
    }
    set_rdb_default pop.check \
	    "/usr/local/sbin/checkup -q $rdb(pop.server) 1 0.4"
    catch {eval exec $rdb(pop.check)} err1
    if {[expr {$err1 == ""}] && ![winfo exists .f1] &&\
	    [info exists rdb(pop.passwd)]} {
	# This is bad.
	# Should use something like expect to send password.
	catch {eval exec {$rdb(pop.client)} $rdb(pop.args) {$rdb(pop.passwd)}\
		{$rdb(pop.server)}} err2
	if {[expr {$errorCode != "NONE"}] &&\
		[expr {[lindex $errorCode 2] > 1}]} {
	    puts "$err2"
	}
    }
}

proc pop_update {} {
    global rdb monitor_module pop_status
    if {$monitor_module(pop)} {
	pop_client
	after $rdb(pop.interval) pop_update
    }
}

proc pop_start {} {
    global rdb pop_status
    set_rdb_default pop.client "popclient"
    set_rdb_default pop.args "-3 -p"
    set_rdb_default pop.interval 30000
    set_rdb_default pop.row 1
    mk_rows $rdb(pop.row)
    label .pop -text pop -fg $rdb(fg) -bg $rdb(bg)
    pack .pop -side $rdb(side) -in ".row$rdb(pop.row)"
    pop_init
    pop_update
}

proc pop_stop {} {
    destroy .pop
}
